<?php
/**
 * @author Patrick Zambelli
 * GLPI Plugin for NeDi Glpi Synchronization
 * 
 * Import your NeDi Devices into Glpi
 * 
 -------------------------------------------------------------------------
 NetEye ActionLaunchpad 
 -------------------------------------------------------------------------

 LICENSE

 Copyright (C) 2014 by Wuerth Whoenix GmbH
 http://www.wuerth-phoenix.com

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 --------------------------------------------------------------------------
 */

function plugin_nediinventory_install() {
    
    global $DB;

    // Table names:
    // GLPI uses the plugin name, and a model name to create a table name.
    // So it looks like: glpi_plugin_(plugin_name)_(model_name).
    // The class name that handles this table looks like: Plugin(Pluginname)(Modelname).
    // And the file exists as /glpi/plugins/(plugin_name)/inc/(model_name).class.php.

    
    if (!TableExists('glpi_plugin_nediinventory_nediinventory')) {

        // the settings table:
        $query = "CREATE TABLE `glpi_plugin_nediinventory_nediinventory` (
            `id` int(11) NOT NULL auto_increment,
            `param` varchar(1024) NOT NULL,
            `value` varchar(1024) NOT NULL,
            PRIMARY KEY(`id`)
            ) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
        $DB->query($query) or die("error creating glpi_plugin_nediinventory_nediinventory " . $DB->error());

        $query = "INSERT INTO `glpi`.`glpi_plugin_nediinventory_nediinventory` (`id` , `param` , `value` ) VALUES
        	( NULL , 'default_entityID', '0'),
			( NULL , 'default_stateID', '1'),
        	( NULL , 'nedi_Links_Version', '1_0_8'),
        	( NULL , 'enable_debug', '0');";
        $DB->query($query) or die("error filling values in glpi_plugin_nediinventory_nediinventory " . $DB->error());
        
        // 
        $query = "CREATE TABLE `glpi_plugin_nediinventory_nedilinksneteq` (
            `glpi_networkequipments_id` int(11) NOT NULL,
            `nedi_device` varchar(128) NOT NULL,
            `nedi_device_serial` varchar(32) NOT NULL default '',
            PRIMARY KEY(`nedi_device`)
            ) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
        $DB->query($query) or die("error creating glpi_plugin_nediinventory_nedilinksneteq " . $DB->error());
        
  
        $query = "CREATE TABLE `glpi_plugin_nediinventory_nedilinksdev` (
        		`glpi_peripherals_id` int(11) NOT NULL,
        		`glpi_networkEquipment_id` int(11) NOT NULL,
        		`nedi_modules_serial` varchar(32) NOT NULL default '0',
        		`nedi_module_device` VARCHAR( 64 ) NOT NULL,
        		`nedi_module_slot` VARCHAR( 64 ) NOT NULL ,
        		`installation_status` SET( 'installed', 'uninstalled' ) NOT NULL,
        		`last_discovery` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
            ) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
        $DB->query($query) or die("error creating glpi_plugin_nediinventory_nedilinksdev " . $DB->error());
        
    }

    // CronTask registers your plugin by the class name (PluginNediinventoryNediinventory) and
    // the 2nd parameter as a static method with ‘cron’ prepended to it.
    // So, whenever this runs, it calls PluginNediinventoryNediinventory::cronSyncData(CronTask $object).
    // The 3rd parameter is how often the job should run in seconds.
    // The final parameter is an array of options.
    CronTask::Register('PluginNediinventoryNediinventory', 'SyncNedi', 3600, array('hourmin' => 0, 'hourmax' => 24, 'mode' => CronTask::MODE_EXTERNAL));
 
    return true;
}

function plugin_nediinventory_uninstall() {
    global $DB;
 
    foreach ( array('glpi_plugin_nediinventory_nediinventory', 'glpi_plugin_nediinventory_nedilinksneteq', 'glpi_plugin_nediinventory_nedilinksdev') as $table) { 
        if (TableExists($table)) {
            $query = "DROP TABLE `$table`";
            $DB->query($query) or die("Error deleting $table table");
        }
    }
#    $notif = new Notification();
#    $options = array('itemtype' => 'PluginNediinventoryNediinventory',
#        'event' => 'alert',
#        'FIELDS' => 'id');
#    foreach ($DB->request('glpi_notifications', $options) as $data) {
#        $notif->delete($data);
#    }

    CronTask::Unregister('PluginNediinventoryNediinventory');
    return true;
}

?>
