<?php
/**
 * @author Patrick Zambelli
 * GLPI Plugin for NeDi Glpi Synchronization
 * 
 * Import your NeDi Devices into Glpi
 * 
 -------------------------------------------------------------------------
 NetEye ActionLaunchpad 
 -------------------------------------------------------------------------

 LICENSE

 Copyright (C) 2014 by Wuerth Whoenix GmbH
 http://www.wuerth-phoenix.com

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 --------------------------------------------------------------------------
 */

function plugin_version_nediinventory () {

	return array ('name' => "Nedi Inventory",
                'version' => '1.0.7',
                'author' => 'Patrick Zambelli, Thomas Forrer (Wuerth Phoenix S.R.L.)',
                'license' => 'GPLv2+',
                'homepage' => 'http://neteye-blog.it/',
                'minGlpiVersion' => '0.84'); // For compatibility / no install in version <0.80

}


function plugin_nediinventory_check_prerequisites() {
	global $DB;
	
    if (version_compare(GLPI_VERSION,'0.84','lt') || version_compare(GLPI_VERSION,'0.85','gt')) {
        echo "This plugin Requires GLPI> = 0.84 and GLPI <0.85";
        return false;
    }
    
    
    //Run query to verify that fusioninventory is installed and ACTIVE ( Field Lock Management )
    $query = "SELECT name, state
        	FROM `glpi_plugins`
        	WHERE state = 1 AND directory = 'fusioninventory'";
    $prop_results = $DB->query($query) or die("error on query of NeDi Inventory the FusionInventory Plugin to be active for the field Locks management" . $DB->error());
    if ($prop_results && $DB->numrows($prop_results) == 0) {
    	echo "Nedi Inventory Plugin requires the FusionInventory Plugin to be active for the field Locks management";
    	return false;
    }
    
    //Run Select query on Nedi database to proof SELECT grant
    $query = "show tables from nedi";
    $prop_results = $DB->query($query) or die("error on query to test if GLPI has the Select GRANT on NeDi Tables" . $DB->error());
    if ($prop_results && $DB->numrows($prop_results) == 0) {
    	echo "The Nedi Inventory Plugin requires SELECT GRANT Permissions on NeDi Database. Permission not given.";
    	return false;
    }
    
    // We need to check also if The right version of Nedi is installed
    // -> This is done by SPEC file

    return true;
}

function plugin_nediinventory_check_config($verbose=false) {
    if (true) {
        return true;
    }
    if ($verbose) {
        echo 'NediInventory: Installed / not configured';
    }
    return false;
}

function plugin_init_nediinventory () {
    global $PLUGIN_HOOKS,$CFG_GLPI;

    $PLUGIN_HOOKS['csrf_compliant']['nediinventory'] = true;

    // register the CONFIGURATION PHP PAGE:
    $PLUGIN_HOOKS['config_page']['nediinventory'] = 'front/config.form.php';

    // register a new TAB ON NETWORKDEVICES:
    // You will notice the naming class, they all begin with Plugin (with a capital P),
    // then the name of the plugin (also capitalized) and finally own the class with him as an uppercase name.
    // This name should reflect the purpose of the better class
    // The class is the engine of the plugin. They are grouped in a single folder (inc) and they are named as follows:. <nomduplugin> Class.php (all lowercase).

    // SEE inc/nediinventory.class.php
    // The plugin tab gets its name from PluginRstatusRstatus::getTabNameForItem. The content appended to the tab is generated by an AJAX call to PluginRstatusRstatus::displayTabContentForItem. 
    Plugin::registerClass('PluginNediinventoryNediinventory', array( 'addtabon' => array('NetworkEquipment', 'Peripheral')));

    // SEE inc/config.class.php
    Plugin::registerClass('PluginNediinventoryConfig');
}

?>
