<?php
/*
 * @version $Id: nediinventory_netEqList.php 2014-06-05 $
 -------------------------------------------------------------------------
 This Report is part of the NediInventory Plugin 
 Integration into the Reports Plugin of GLPI version 1.7 for GLPI 0.84
 Copyright (C) 2014 by WuerthPhoenix Srl.
 Author: Patrick Zambelli

 http://www.neteye-blog.com/
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI NediInventory Plugin

 NediInventory is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 NediInventory is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with reports. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

$USEDBREPLICATE        = 1;
$DBCONNECTION_REQUIRED = 0; // not really a big SQL request

include ("../../../../inc/includes.php");


// Report with Modules
$report = new PluginReportsAutoReport(__($LANG['plugin_reports']['nediinventory'][1], 'reports'));


//Filter Criteria
$netEqName = new PluginReportsTextCriteria($report, 'N.name', __($LANG['plugin_reports']['nediinventory'][10].' (Like)'));
$periferalName = new PluginReportsTextCriteria($report, 'P.name', __($LANG['plugin_reports']['nediinventory'][21].' (Like)'));

$netEqManufacturer = new PluginReportsDropdownCriteria($report, 'NMAN.id', 'glpi_manufacturers', __($LANG['plugin_reports']['nediinventory'][15]));
$periferalType = new PluginReportsDropdownCriteria($report, 'P.peripheraltypes_id', 'glpi_peripheraltypes', __($LANG['plugin_reports']['nediinventory'][20]));

$netEqModel = new PluginReportsDropdownCriteria($report, 'N.networkequipmentmodels_id', 'glpi_networkequipmentmodels', __($LANG['plugin_reports']['nediinventory'][12]));
$periferalModel = new PluginReportsDropdownCriteria($report, 'P.peripheralmodels_id', 'glpi_peripheralmodels', __($LANG['plugin_reports']['nediinventory'][23]));

$netEqFirmware = new PluginReportsDropdownCriteria($report, 'N.networkequipmentfirmwares_id', 'glpi_networkequipmentfirmwares', __($LANG['plugin_reports']['nediinventory'][13]));
$periferalFirmware = new PluginReportsTextCriteria($report, 'P.brand', __($LANG['plugin_reports']['nediinventory'][25].' (Like)'));





//Sort Criteria
$report->setColumns(array(
	//Show the NetEquipment Name with a Link to its ID
	new PluginReportsColumnLink('nid', __($LANG['plugin_reports']['nediinventory'][10]), 'NetworkEquipment',
        	array('sorton' => 'nname,ptype,pname')),
	new PluginReportsColumn('nserial', __($LANG['plugin_reports']['nediinventory'][11]),
        	array('sorton' => 'nserial,ptype,pname')),
	new PluginReportsColumn('nmanufacturer', __($LANG['plugin_reports']['nediinventory'][15]),
        	array('sorton' => 'nmanufacturer,ptype,pname')),
	new PluginReportsColumn('nmodel', __($LANG['plugin_reports']['nediinventory'][12]),
        	array('sorton' => 'nmodel,ptype,pname')),
	new PluginReportsColumn('nfirmware', __($LANG['plugin_reports']['nediinventory'][13]),
        	array('sorton' => 'nfirmware,ptype,pname')),
	new PluginReportsColumn('ncomment', __($LANG['plugin_reports']['nediinventory'][14]),
        	array('sorton' => 'ncomment,ptype,pname')),

	//Sorting of Device Columns: First sort for Column, then for NetworkEQ in order to keep grouping working
	new PluginReportsColumnLink('pid', __($LANG['plugin_reports']['nediinventory'][21]), 'Peripheral',
        	array('sorton' => 'ptype,pname,nid,ptype')),
        new PluginReportsColumn('pserial', __($LANG['plugin_reports']['nediinventory'][22]),
        	array('sorton' => 'ptype')),
        new PluginReportsColumn('ptype', __($LANG['plugin_reports']['nediinventory'][20]),
        	array('sorton' => 'ptype,nid,pname')),
        new PluginReportsColumn('pmodel', __($LANG['plugin_reports']['nediinventory'][23]),
        	array('sorton' => 'pmodel,nid,pname')),
        new PluginReportsColumn('pfirmware', __($LANG['plugin_reports']['nediinventory'][25]),
        	array('sorton' => 'pfirmware,nid,pname')),
        new PluginReportsColumn('pcomment', __($LANG['plugin_reports']['nediinventory'][24]),
        	array('sorton' => 'pcomment,nid,pname')),
	)
);


//Display criterias form is needed
$report->displayCriteriasForm();


// SQL statement
$query = "
(
 SELECT  N.id AS nid,
        N.name AS nname,
        N.serial AS nserial,
	NMAN.name AS nmanufacturer,
        NM.name AS nmodel,
        NF.name AS nfirmware,
        N.comment AS ncomment,
        P.id AS pid,
        P.name AS pname, 
        P.serial AS pserial,
        PT.name AS ptype,
        PM.name AS pmodel,
        P.brand AS pfirmware,
        P.comment AS pcomment
 FROM `glpi_networkequipments` N
  LEFT JOIN glpi.glpi_plugin_nediinventory_nedilinksdev R ON N.id = R.glpi_networkEquipment_id
  LEFT JOIN `glpi_peripherals` P ON R.glpi_peripherals_id = P.id
  LEFT JOIN `glpi_networkequipmentmodels` NM ON NM.id = N.networkequipmentmodels_id
  LEFT JOIN `glpi_networkequipmentfirmwares` NF ON NF.id = N.networkequipmentfirmwares_id
  LEFT JOIN `glpi_manufacturers` NMAN ON NMAN.id = N.manufacturers_id
  LEFT JOIN `glpi_peripheraltypes` PT ON PT.id = P.peripheraltypes_id
  LEFT JOIN `glpi_peripheralmodels` PM ON PM.id = P.peripheralmodels_id
 WHERE R.installation_status = 'installed' AND N.is_deleted = 0 AND N.is_template = 0
".$report->addSqlCriteriasRestriction()." 
)
UNION
(
 SELECT 
   N.id AS nid,
   N.name AS nname,
   N.serial AS nserial,
   NMAN.name AS nmanufacturer,
   NM.name AS nmodel,
   NF.name AS nfirmware,
   N.comment AS ncomment,
   '/' AS pid,
   '/' AS pname, 
   '/' AS pserial,
   '/' AS ptype,
   '/' AS pmodel,
   '/' AS pfirmware,
   '/' AS pcomment
  FROM glpi_networkequipments N 
  LEFT JOIN `glpi_networkequipmentmodels` NM ON NM.id = N.networkequipmentmodels_id
  LEFT JOIN `glpi_networkequipmentfirmwares` NF ON NF.id = N.networkequipmentfirmwares_id
  LEFT JOIN `glpi_manufacturers` NMAN ON NMAN.id = N.manufacturers_id
  LEFT JOIN glpi.glpi_plugin_nediinventory_nedilinksdev R ON N.id = R.glpi_networkEquipment_id
  LEFT JOIN `glpi_peripherals` P ON R.glpi_peripherals_id = P.id
  WHERE N.is_deleted = 0 AND N.is_template = 0 ".$report->addSqlCriteriasRestriction()." AND N.id NOT IN 
  (
	SELECT  N.id AS nid
	FROM `glpi_networkequipments` N
	  LEFT JOIN glpi.glpi_plugin_nediinventory_nedilinksdev R ON N.id = R.glpi_networkEquipment_id
	  LEFT JOIN `glpi_peripherals` P ON R.glpi_peripherals_id = P.id
	  LEFT JOIN `glpi_networkequipmentmodels` NM ON NM.id = N.networkequipmentmodels_id
	  LEFT JOIN `glpi_networkequipmentfirmwares` NF ON NF.id = N.networkequipmentfirmwares_id
	  LEFT JOIN `glpi_peripheraltypes` PT ON PT.id = P.peripheraltypes_id
	  LEFT JOIN `glpi_peripheralmodels` PM ON PM.id = P.peripheralmodels_id
	WHERE R.installation_status = 'installed' AND N.is_deleted = 0 AND N.is_template = 0
  )
)"
.$report->getOrderBy('nid');


$report->setGroupBy(array('nid','nserial','nmanufacturer','nmodel','nfirmware','ncomment'));
$report->setSqlRequest($query);
$report->execute();



?>
